#!/bin/sh
#	Accompanies arXiv submission, Hatton and Warr Jun 2018.
#
#	Reduces data by first tokenising it and then concatenating.
#
#	Copyright Les Hatton, 2018-.
#	Released under the GNU GPL.
#
#	Revision:	$Revision: 1.1 $
#	Date:	$Date: 2017/01/22 17:22:59 $
#-----------------------------------------
if test $# -ne 0
then
	echo "Usage: $0"
	exit
fi

prepareDatasets () {
	if test ! -f $TREMBL
	then
		echo "Protein data ............................................."
		echo "The unprocessed UniProt dataset $TREMBL is not available."
		echo "Checking to see if the processed form is available ..."

		if test ! -f ${VERSION}_trembl_pairs.dat
		then
			echo "... no processed data available.  See 1-downloadDataSets.sh."
			exit
		else
			echo "The processed form ${VERSION}_trembl_pairs.dat is available.  This will be used."
		fi
	else
		echo "The unprocessed UniProt dataset $TREMBL is available."
		echo "Checking to see if the processed form is present and if not"
		echo "it will be created."

		if test ! -f ${VERSION}_trembl_pairs.dat
		then
			echo "Creating the pairs dataset ${VERSION}_trembl_pairs.dat"
			echo "This may take a while ........................"
			cat $TREMBL | ./tremblToTok.pl 	> ${TREMBL}_trembl_pairs.raw
#
#			The .raw file is in the form 322,20,H1KWY9_9EURY,Methanotorris formicicus Mc-S-70 etc.
#			(4 fields and comma separated).  We need to sort on the first field or sort sorts on lines.
#
			cat  ${VERSION}_trembl_pairs.raw	| sort -n -t',' -k1,1	> ${VERSION}_trembl_pairs.dat
			rm -f ${VERSION}_trembl_pairs.raw
		fi

		echo "The processed form ${VERSION}_trembl_pairs.dat is available.  This will be used."
	fi
}


echo "Preparing 15-07 dataset ..."
VERSION=15-07
TREMBL=${VERSION}/uniprot_trembl.fasta
prepareDatasets

echo "Preparing 17-03 dataset ..."
VERSION=17-03
TREMBL=${VERSION}/uniprot_trembl.fasta
prepareDatasets

echo "Preparation of processed software datasets completed:-"
ls -l *.dat
echo
#
#	Finally, we will need the normaliser.
#
if test ! -f normalise
then
	gcc -o normalise normalise.c
fi

echo "You may now continue with the processing stages, 3-xxxx.sh for each figure"
echo "shown in the Main Paper and the Supplementary Materials."
