#--------------
#	R file to generate the 3D plots from the alpha beta slope grid of the CoHSI equation.
#
#	Author:	Les Hatton, with grateful thanks to Karline Soetaert and many other
#	contributors to the R project and its associated graphics support.
#
#	Revision:	$Revision$
#	Date:	$Date$
#--------------
##	Pull in the necessary libraries.  If not present, use install.packages("tgp") etc.
#
library(tgp)
library(akima)
library(plot3D)
library(reshape2)
#
#	We have one csv file created by gridAlphaBeta.sh with columns
#	alpha,beta,mean,median,mode
#
#	First we create the full data frames.
#
fullabframe <- read.csv(file="gridAlphaBetaSlope.csv", header=TRUE, sep=",")
#
#	The colnames are given by
#
colnames(fullabframe)
#	[1] "alpha"  "beta"   "slope" "rsquared"
#
#	We now coerce these into matrices using the acast() function from
#	the reshape2 library.
#
abslope <- fullabframe[c("alpha","beta","slope")]
abrsquared <- fullabframe[c("alpha","beta","rsquared")]

mabslope <- acast(abslope,alpha~beta, value.var="slope")
mabrsquared <- acast(abrsquared,alpha~beta, value.var="rsquared")
#
#	These are same for each plot so just use mabmean.
#
x <- seq(3, 5, length.out = nrow(mabslope))
y <- seq(0, 1, length.out = ncol(mabslope))
#--------------
##	Plot of slope with accompanying contour.
#
postscript(file = "slopeAlphaBeta.eps", horizontal = FALSE)
par(mfrow = c(1,1))
persp3D( x, y, z = mabslope, zlim = c(-5, 0), phi = 20, bty = "b",   
	colkey = list(length = 0.2, width = 0.4, shift = 0.15, cex.axis = 0.8, cex.clab = 0.85), 
	lighting = FALSE, contour = TRUE, theta = 60, ticktype = "detailed",
	xlab = "alpha", ylab = "beta", zlab = "slope",
#	main = "Mean plotted as a function of (alpha,beta)",
	clab = c("slope"), plot = FALSE)

image3D( x, y, z = -5, colvar = mabslope, add = TRUE, resfac = c(4,4),
	colkey = FALSE, contour = TRUE,
	clab = c("alpha","beta"),
	plot = TRUE)
dev.off()
#--------------
##	Plot of rsquared with accompanying contour.
#
postscript(file = "rsquaredAlphaBeta.eps", horizontal = FALSE)
par(mfrow = c(1,1))
persp3D( x, y, z = mabrsquared, zlim = c(0, 1.2), phi = 20, bty = "b",   
	colkey = list(length = 0.2, width = 0.4, shift = 0.15, cex.axis = 0.8, cex.clab = 0.85), 
	lighting = FALSE, contour = TRUE, theta = 60, ticktype = "detailed",
	xlab = "alpha", ylab = "beta", zlab = "rsquared",
#	main = "Mean plotted as a function of (alpha,beta)",
	clab = c("rsquared"), plot = FALSE)

image3D( x, y, z = 0, colvar = mabrsquared, add = TRUE, resfac = c(4,4),
	colkey = FALSE, contour = TRUE,
	clab = c("alpha","beta"),
	plot = TRUE)
dev.off()
#--------------

#	par("ask" = FALSE)
