#!/usr/bin/perl
#
# 	Go through the (gigantic) Trembl file extracting protein lengths and
#	unique alphabets.  This is very stripped down for speed.
#
#	Copyright Les Hatton, 2013-.
#	Released under the GNU GPL.
#
#	Revision:	$Revision: 1.1 $
#	Date:	$Date: 2017/01/21 16:19:11 $
#-----------------------------------------------------------------

use strict;
use warnings;
use Getopt::Std;

my	(%opt);
my	$status	= 0;

#-----------------------------------------------------------------
getopts('t', \%opt);
#-----------------------------------------------------------------
sub	processSequence($$$)
{
	my	($sequence,$tax,$species)	= @_;

	my	$lenseq			= length($sequence);
	my	%unmodaminofreq	= ();
	foreach my $char (split "", $sequence)
	{
		++$unmodaminofreq{$char};
	}

	my	$amino_unique_before_ptm	= 0;
	foreach my $uniquechar   (sort keys %unmodaminofreq)
	{
		++$amino_unique_before_ptm;
	}

	if ( defined $opt{t} )
	{
		printf "%d\n", $lenseq;
	}
	else
	{
		printf "%d,%d,%s,%s\n", $lenseq, $amino_unique_before_ptm, $tax, $species; 
	}
}
#-----------------------------------------------------------------

my	$sequence				= "";
my	%unmodaminofreq		= ();
my	$amino_unique_before_ptm	= 0;
my	$lenseq				= 0;
my	$tax1				= "";
my	$tax2				= "";
my	$tax3				= "";
my	$species				= "";

my	$first				= 1;

while( my $line = <STDIN> )
{
	chomp	$line;
#
#	We pick up the organism name up to the next keyword =, which could be GN= but
#	is usually PE=.
#
	if ( $line =~ /^>tr\|([A-Z0-9]+)\|([A-Z0-9_]+)\s+(.*)OS=([^=]+)=/ )
	{
		if ( $sequence ne "" )
		{
#
#			Process sequence.
#			The species will now end in the next keyfield GN or PE which
#			has had the = stripped.
#
			$species	=~ s/ GN|PE$//;
			&processSequence( $sequence, $tax2, $species );
			undef	$sequence;
		}

		$tax1	= $1;
		$tax2	= $2;
		$tax3	= $3;
		$species	= $4;
	}
	else
	{
#
#		Protein sequence.
#
		$sequence .= $line;
	}
}
#
#	Spit out last one.
#
&processSequence( $sequence, $tax2 );

exit($status);
#-----------------------------------------------------------------
